@@ -151,6 +151,7 @@ def test_tags_from_path_plist_text(tmpdir):
 @pytest.mark.parametrize(
     ('filename', 'expected'),
     (
+        ('.salt-lint', {'text', 'salt-lint', 'yaml'}),
         ('test.py', {'text', 'python'}),
         ('test.mk', {'text', 'makefile'}),
         ('Makefile', {'text', 'makefile'}),
@@ -170,6 +171,7 @@ def test_tags_from_path_plist_text(tmpdir):
         ('build.jenkinsfile', {'text', 'groovy', 'jenkins'}),
         ('meson.build', {'text', 'meson'}),
         ('meson_options.txt', {'text', 'plain-text', 'meson'}),
+        ('Vagrantfile', {'text', 'ruby'}),
 
         # does not set binary / text
         ('f.plist', {'plist'}),
